# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.validate import validate_pb2 as validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='common/common.proto',
  package='sensory.api.common',
  syntax='proto3',
  serialized_options=b'\n\032ai.sensorycloud.api.commonB\025SensoryApiCommonProtoP\001Z8gitlab.com/sensory-cloud/server/titan.git/pkg/api/common',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x63ommon/common.proto\x12\x12sensory.api.common\x1a\x17validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"U\n\x18\x43ompressionConfiguration\x12\x39\n\x0c\x63ompressions\x18\x01 \x03(\x0e\x32#.sensory.api.common.CompressionType\"Y\n\rTokenResponse\x12\x13\n\x0b\x61\x63\x63\x65ssToken\x18\x01 \x01(\t\x12\x11\n\texpiresIn\x18\x02 \x01(\x05\x12\r\n\x05keyId\x18\x03 \x01(\t\x12\x11\n\ttokenType\x18\x04 \x01(\t\"A\n\rServiceHealth\x12\x11\n\tisHealthy\x18\x01 \x01(\x08\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xc7\x01\n\x14ServerHealthResponse\x12\x11\n\tisHealthy\x18\x01 \x01(\x08\x12\x15\n\rserverVersion\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x33\n\x08services\x18\x04 \x03(\x0b\x32!.sensory.api.common.ServiceHealth\x12\x32\n\nserverType\x18\x05 \x01(\x0e\x32\x1e.sensory.api.common.ServerType\x12\x10\n\x08isLeader\x18\x06 \x01(\x08\"\x83\x01\n\rSystemSummary\x12\x35\n\x03\x63pu\x18\x01 \x01(\x0b\x32\x1e.sensory.api.common.CpuSummaryB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12;\n\x06memory\x18\x02 \x01(\x0b\x32!.sensory.api.common.MemorySummaryB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xa5\x01\n\nCpuSummary\x12\x0c\n\x04user\x18\x01 \x01(\x04\x12\x0c\n\x04nice\x18\x02 \x01(\x04\x12\x0e\n\x06system\x18\x03 \x01(\x04\x12\x0c\n\x04idle\x18\x04 \x01(\x04\x12\x0e\n\x06ioWait\x18\x05 \x01(\x04\x12\x0b\n\x03irq\x18\x06 \x01(\x04\x12\x0f\n\x07softIrq\x18\x07 \x01(\x04\x12\r\n\x05steal\x18\x08 \x01(\x04\x12\r\n\x05guest\x18\t \x01(\x04\x12\x11\n\tguestNice\x18\n \x01(\x04\"H\n\rMemorySummary\x12\x10\n\x08memTotal\x18\x01 \x01(\x04\x12\x0f\n\x07memFree\x18\x02 \x01(\x04\x12\x14\n\x0cmemAvailable\x18\x03 \x01(\x04\"D\n\rGenericClient\x12\x1a\n\x08\x63lientId\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12\x17\n\x06secret\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\n\"\x88\x01\n\x0eTenantResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12-\n\tcreatedAt\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tupdatedAt\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"]\n\x11PaginationOptions\x12\x10\n\x08ordering\x18\x01 \x01(\t\x12\x11\n\tdecending\x18\x02 \x01(\x08\x12\x11\n\tpageIndex\x18\x03 \x01(\x05\x12\x10\n\x08pageSize\x18\x04 \x01(\x05\"\xc2\x01\n\x12PaginationResponse\x12\x10\n\x08ordering\x18\x01 \x01(\t\x12\x11\n\tdecending\x18\x02 \x01(\x08\x12\x19\n\x11possibleOrderings\x18\x03 \x03(\t\x12\x12\n\ntotalCount\x18\x04 \x01(\x03\x12\x10\n\x08pageSize\x18\x05 \x01(\x05\x12\x15\n\rprevPageIndex\x18\x06 \x01(\x05\x12\x18\n\x10\x63urrentPageIndex\x18\x07 \x01(\x05\x12\x15\n\rnextPageIndex\x18\x08 \x01(\x05\"4\n\x0f\x45nrollmentToken\x12\r\n\x05token\x18\x01 \x01(\x0c\x12\x12\n\nexpiration\x18\x02 \x01(\x03\"\x86\x01\n\x10\x43reateKeyRequest\x12\x17\n\x04name\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x36\n\x07keyType\x18\x02 \x01(\x0e\x32\x1b.sensory.api.common.KeyTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\r\n\x05value\x18\x03 \x01(\t\x12\x12\n\nexpiration\x18\x04 \x01(\x03\"\x8d\x01\n\x0bKeyResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\x07keyType\x18\x03 \x01(\x0e\x32\x1b.sensory.api.common.KeyType\x12\x12\n\nexpiration\x18\x04 \x01(\x03\x12\x10\n\x08tenantId\x18\x05 \x01(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08*\x16\n\x04Void\x12\x0e\n\nVOID_VALUE\x10\x00*Q\n\x07KeyType\x12\x0e\n\nPUBLIC_KEY\x10\x00\x12\x16\n\x12PUBLIC_KEY_ED25519\x10\x01\x12\x11\n\rSHARED_SECRET\x10\x03\x12\x0b\n\x07\x41\x45S_256\x10\x04*4\n\x0b\x46\x65\x61tureFlag\x12\x0c\n\x08TSSV_ALL\x10\x00\x12\n\n\x06TS_ALL\x10\x01\x12\x0b\n\x07TNL_ALL\x10\x02*\xa4\x04\n\tModelType\x12\x0b\n\x07UNKNOWN\x10\x00\x12$\n VOICE_BIOMETRIC_TEXT_INDEPENDENT\x10\x01\x12\x1c\n\x18VOICE_BIOMETRIC_WAKEWORD\x10\x02\x12\x18\n\x14VOICE_EVENT_WAKEWORD\x10\x03\x12\x1c\n\x18VOICE_TRANSCRIBE_GRAMMAR\x10\x04\x12\'\n#VOICE_TRANSCRIBE_COMMAND_AND_SEARCH\x10\x05\x12(\n$VOICE_RECOGNITION_ACTIVITY_DETECTION\x10\x06\x12\x1b\n\x17VOICE_FEATURE_EXTRACTOR\x10\x07\x12\"\n\x1eVOICE_BIOMETRIC_LIVENESS_DIGIT\x10\x08\x12\"\n\x1eVOICE_BIOMETRIC_TEXT_DEPENDENT\x10\t\x12\x13\n\x0fVOICE_SYNTHESIS\x10\n\x12\x1a\n\x16SOUND_EVENT_ENROLLABLE\x10\x64\x12\x1c\n\x18SOUND_EVENT_REVALIDATION\x10\x65\x12\x15\n\x11SOUND_EVENT_FIXED\x10\x66\x12\x15\n\x11SOUND_SCENE_FIXED\x10g\x12\x13\n\x0e\x46\x41\x43\x45_BIOMETRIC\x10\xc9\x01\x12\x15\n\x10\x46\x41\x43\x45_RECOGNITION\x10\xca\x01\x12\x17\n\x12OBJECT_RECOGNITION\x10\xcb\x01\x12\x14\n\x0fIMAGE_TRANSFORM\x10\xcc\x01*J\n\x0eTechnologyType\x12\x0b\n\x07NOT_SET\x10\x00\x12\x08\n\x04TSSV\x10\x01\x12\x06\n\x02TS\x10\x02\x12\x07\n\x03TNL\x10\x03\x12\x07\n\x03STT\x10\x04\x12\x07\n\x03TTS\x10\x05*&\n\x0f\x43ompressionType\x12\x13\n\x0fIMAGE_GRAYSCALE\x10\x00*|\n\nClientType\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x44\x45VICE\x10\x01\x12\x0b\n\x07\x43LUSTER\x10\x02\x12\x08\n\x04USER\x10\x03\x12\x0e\n\nSUPER_USER\x10\x04\x12\x10\n\x0c\x42ILLING_USER\x10\x05\x12\x12\n\x0eREAD_ONLY_USER\x10\x06\x12\x08\n\x04ROOT\x10\x64*g\n\x0eUsageEventType\x12\x12\n\x0e\x41UTHENTICATION\x10\x00\x12\x0f\n\x0bRECOGNITION\x10\x01\x12\x0e\n\nENROLLMENT\x10\x02\x12\r\n\tSYNTHESIS\x10\x03\x12\x11\n\rTRANSCRIPTION\x10\x04*\x1f\n\nServerType\x12\t\n\x05TITAN\x10\x00\x12\x06\n\x02IO\x10\x01\x42o\n\x1a\x61i.sensorycloud.api.commonB\x15SensoryApiCommonProtoP\x01Z8gitlab.com/sensory-cloud/server/titan.git/pkg/api/commonb\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_VOID = _descriptor.EnumDescriptor(
  name='Void',
  full_name='sensory.api.common.Void',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VOID_VALUE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1760,
  serialized_end=1782,
)
_sym_db.RegisterEnumDescriptor(_VOID)

Void = enum_type_wrapper.EnumTypeWrapper(_VOID)
_KEYTYPE = _descriptor.EnumDescriptor(
  name='KeyType',
  full_name='sensory.api.common.KeyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PUBLIC_KEY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC_KEY_ED25519', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_SECRET', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AES_256', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1784,
  serialized_end=1865,
)
_sym_db.RegisterEnumDescriptor(_KEYTYPE)

KeyType = enum_type_wrapper.EnumTypeWrapper(_KEYTYPE)
_FEATUREFLAG = _descriptor.EnumDescriptor(
  name='FeatureFlag',
  full_name='sensory.api.common.FeatureFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TSSV_ALL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TS_ALL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TNL_ALL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1867,
  serialized_end=1919,
)
_sym_db.RegisterEnumDescriptor(_FEATUREFLAG)

FeatureFlag = enum_type_wrapper.EnumTypeWrapper(_FEATUREFLAG)
_MODELTYPE = _descriptor.EnumDescriptor(
  name='ModelType',
  full_name='sensory.api.common.ModelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_BIOMETRIC_TEXT_INDEPENDENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_BIOMETRIC_WAKEWORD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_EVENT_WAKEWORD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_TRANSCRIBE_GRAMMAR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_TRANSCRIBE_COMMAND_AND_SEARCH', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_RECOGNITION_ACTIVITY_DETECTION', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_FEATURE_EXTRACTOR', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_BIOMETRIC_LIVENESS_DIGIT', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_BIOMETRIC_TEXT_DEPENDENT', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VOICE_SYNTHESIS', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOUND_EVENT_ENROLLABLE', index=11, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOUND_EVENT_REVALIDATION', index=12, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOUND_EVENT_FIXED', index=13, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOUND_SCENE_FIXED', index=14, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FACE_BIOMETRIC', index=15, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FACE_RECOGNITION', index=16, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_RECOGNITION', index=17, number=203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_TRANSFORM', index=18, number=204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1922,
  serialized_end=2470,
)
_sym_db.RegisterEnumDescriptor(_MODELTYPE)

ModelType = enum_type_wrapper.EnumTypeWrapper(_MODELTYPE)
_TECHNOLOGYTYPE = _descriptor.EnumDescriptor(
  name='TechnologyType',
  full_name='sensory.api.common.TechnologyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TSSV', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TNL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TTS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2472,
  serialized_end=2546,
)
_sym_db.RegisterEnumDescriptor(_TECHNOLOGYTYPE)

TechnologyType = enum_type_wrapper.EnumTypeWrapper(_TECHNOLOGYTYPE)
_COMPRESSIONTYPE = _descriptor.EnumDescriptor(
  name='CompressionType',
  full_name='sensory.api.common.CompressionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMAGE_GRAYSCALE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2548,
  serialized_end=2586,
)
_sym_db.RegisterEnumDescriptor(_COMPRESSIONTYPE)

CompressionType = enum_type_wrapper.EnumTypeWrapper(_COMPRESSIONTYPE)
_CLIENTTYPE = _descriptor.EnumDescriptor(
  name='ClientType',
  full_name='sensory.api.common.ClientType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUPER_USER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BILLING_USER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ONLY_USER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROOT', index=7, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2588,
  serialized_end=2712,
)
_sym_db.RegisterEnumDescriptor(_CLIENTTYPE)

ClientType = enum_type_wrapper.EnumTypeWrapper(_CLIENTTYPE)
_USAGEEVENTTYPE = _descriptor.EnumDescriptor(
  name='UsageEventType',
  full_name='sensory.api.common.UsageEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTHENTICATION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECOGNITION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENROLLMENT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNTHESIS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSCRIPTION', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2714,
  serialized_end=2817,
)
_sym_db.RegisterEnumDescriptor(_USAGEEVENTTYPE)

UsageEventType = enum_type_wrapper.EnumTypeWrapper(_USAGEEVENTTYPE)
_SERVERTYPE = _descriptor.EnumDescriptor(
  name='ServerType',
  full_name='sensory.api.common.ServerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TITAN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2819,
  serialized_end=2850,
)
_sym_db.RegisterEnumDescriptor(_SERVERTYPE)

ServerType = enum_type_wrapper.EnumTypeWrapper(_SERVERTYPE)
VOID_VALUE = 0
PUBLIC_KEY = 0
PUBLIC_KEY_ED25519 = 1
SHARED_SECRET = 3
AES_256 = 4
TSSV_ALL = 0
TS_ALL = 1
TNL_ALL = 2
UNKNOWN = 0
VOICE_BIOMETRIC_TEXT_INDEPENDENT = 1
VOICE_BIOMETRIC_WAKEWORD = 2
VOICE_EVENT_WAKEWORD = 3
VOICE_TRANSCRIBE_GRAMMAR = 4
VOICE_TRANSCRIBE_COMMAND_AND_SEARCH = 5
VOICE_RECOGNITION_ACTIVITY_DETECTION = 6
VOICE_FEATURE_EXTRACTOR = 7
VOICE_BIOMETRIC_LIVENESS_DIGIT = 8
VOICE_BIOMETRIC_TEXT_DEPENDENT = 9
VOICE_SYNTHESIS = 10
SOUND_EVENT_ENROLLABLE = 100
SOUND_EVENT_REVALIDATION = 101
SOUND_EVENT_FIXED = 102
SOUND_SCENE_FIXED = 103
FACE_BIOMETRIC = 201
FACE_RECOGNITION = 202
OBJECT_RECOGNITION = 203
IMAGE_TRANSFORM = 204
NOT_SET = 0
TSSV = 1
TS = 2
TNL = 3
STT = 4
TTS = 5
IMAGE_GRAYSCALE = 0
INVALID = 0
DEVICE = 1
CLUSTER = 2
USER = 3
SUPER_USER = 4
BILLING_USER = 5
READ_ONLY_USER = 6
ROOT = 100
AUTHENTICATION = 0
RECOGNITION = 1
ENROLLMENT = 2
SYNTHESIS = 3
TRANSCRIPTION = 4
TITAN = 0
IO = 1



_COMPRESSIONCONFIGURATION = _descriptor.Descriptor(
  name='CompressionConfiguration',
  full_name='sensory.api.common.CompressionConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compressions', full_name='sensory.api.common.CompressionConfiguration.compressions', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=186,
)


_TOKENRESPONSE = _descriptor.Descriptor(
  name='TokenResponse',
  full_name='sensory.api.common.TokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accessToken', full_name='sensory.api.common.TokenResponse.accessToken', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiresIn', full_name='sensory.api.common.TokenResponse.expiresIn', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyId', full_name='sensory.api.common.TokenResponse.keyId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tokenType', full_name='sensory.api.common.TokenResponse.tokenType', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=277,
)


_SERVICEHEALTH = _descriptor.Descriptor(
  name='ServiceHealth',
  full_name='sensory.api.common.ServiceHealth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='isHealthy', full_name='sensory.api.common.ServiceHealth.isHealthy', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.common.ServiceHealth.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='sensory.api.common.ServiceHealth.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=344,
)


_SERVERHEALTHRESPONSE = _descriptor.Descriptor(
  name='ServerHealthResponse',
  full_name='sensory.api.common.ServerHealthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='isHealthy', full_name='sensory.api.common.ServerHealthResponse.isHealthy', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverVersion', full_name='sensory.api.common.ServerHealthResponse.serverVersion', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.common.ServerHealthResponse.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='services', full_name='sensory.api.common.ServerHealthResponse.services', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverType', full_name='sensory.api.common.ServerHealthResponse.serverType', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLeader', full_name='sensory.api.common.ServerHealthResponse.isLeader', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=546,
)


_SYSTEMSUMMARY = _descriptor.Descriptor(
  name='SystemSummary',
  full_name='sensory.api.common.SystemSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu', full_name='sensory.api.common.SystemSummary.cpu', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory', full_name='sensory.api.common.SystemSummary.memory', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=680,
)


_CPUSUMMARY = _descriptor.Descriptor(
  name='CpuSummary',
  full_name='sensory.api.common.CpuSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='sensory.api.common.CpuSummary.user', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nice', full_name='sensory.api.common.CpuSummary.nice', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system', full_name='sensory.api.common.CpuSummary.system', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle', full_name='sensory.api.common.CpuSummary.idle', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ioWait', full_name='sensory.api.common.CpuSummary.ioWait', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='irq', full_name='sensory.api.common.CpuSummary.irq', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='softIrq', full_name='sensory.api.common.CpuSummary.softIrq', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steal', full_name='sensory.api.common.CpuSummary.steal', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guest', full_name='sensory.api.common.CpuSummary.guest', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='guestNice', full_name='sensory.api.common.CpuSummary.guestNice', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=848,
)


_MEMORYSUMMARY = _descriptor.Descriptor(
  name='MemorySummary',
  full_name='sensory.api.common.MemorySummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='memTotal', full_name='sensory.api.common.MemorySummary.memTotal', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memFree', full_name='sensory.api.common.MemorySummary.memFree', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memAvailable', full_name='sensory.api.common.MemorySummary.memAvailable', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=850,
  serialized_end=922,
)


_GENERICCLIENT = _descriptor.Descriptor(
  name='GenericClient',
  full_name='sensory.api.common.GenericClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientId', full_name='sensory.api.common.GenericClient.clientId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\260\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='sensory.api.common.GenericClient.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=992,
)


_TENANTRESPONSE = _descriptor.Descriptor(
  name='TenantResponse',
  full_name='sensory.api.common.TenantResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.common.TenantResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.common.TenantResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createdAt', full_name='sensory.api.common.TenantResponse.createdAt', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updatedAt', full_name='sensory.api.common.TenantResponse.updatedAt', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=995,
  serialized_end=1131,
)


_PAGINATIONOPTIONS = _descriptor.Descriptor(
  name='PaginationOptions',
  full_name='sensory.api.common.PaginationOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ordering', full_name='sensory.api.common.PaginationOptions.ordering', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decending', full_name='sensory.api.common.PaginationOptions.decending', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pageIndex', full_name='sensory.api.common.PaginationOptions.pageIndex', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pageSize', full_name='sensory.api.common.PaginationOptions.pageSize', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1133,
  serialized_end=1226,
)


_PAGINATIONRESPONSE = _descriptor.Descriptor(
  name='PaginationResponse',
  full_name='sensory.api.common.PaginationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ordering', full_name='sensory.api.common.PaginationResponse.ordering', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decending', full_name='sensory.api.common.PaginationResponse.decending', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='possibleOrderings', full_name='sensory.api.common.PaginationResponse.possibleOrderings', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalCount', full_name='sensory.api.common.PaginationResponse.totalCount', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pageSize', full_name='sensory.api.common.PaginationResponse.pageSize', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prevPageIndex', full_name='sensory.api.common.PaginationResponse.prevPageIndex', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currentPageIndex', full_name='sensory.api.common.PaginationResponse.currentPageIndex', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nextPageIndex', full_name='sensory.api.common.PaginationResponse.nextPageIndex', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1229,
  serialized_end=1423,
)


_ENROLLMENTTOKEN = _descriptor.Descriptor(
  name='EnrollmentToken',
  full_name='sensory.api.common.EnrollmentToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='sensory.api.common.EnrollmentToken.token', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='sensory.api.common.EnrollmentToken.expiration', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1425,
  serialized_end=1477,
)


_CREATEKEYREQUEST = _descriptor.Descriptor(
  name='CreateKeyRequest',
  full_name='sensory.api.common.CreateKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.common.CreateKeyRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyType', full_name='sensory.api.common.CreateKeyRequest.keyType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sensory.api.common.CreateKeyRequest.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='sensory.api.common.CreateKeyRequest.expiration', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1480,
  serialized_end=1614,
)


_KEYRESPONSE = _descriptor.Descriptor(
  name='KeyResponse',
  full_name='sensory.api.common.KeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.common.KeyResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.common.KeyResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyType', full_name='sensory.api.common.KeyResponse.keyType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='sensory.api.common.KeyResponse.expiration', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tenantId', full_name='sensory.api.common.KeyResponse.tenantId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='sensory.api.common.KeyResponse.disabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1617,
  serialized_end=1758,
)

_COMPRESSIONCONFIGURATION.fields_by_name['compressions'].enum_type = _COMPRESSIONTYPE
_SERVERHEALTHRESPONSE.fields_by_name['services'].message_type = _SERVICEHEALTH
_SERVERHEALTHRESPONSE.fields_by_name['serverType'].enum_type = _SERVERTYPE
_SYSTEMSUMMARY.fields_by_name['cpu'].message_type = _CPUSUMMARY
_SYSTEMSUMMARY.fields_by_name['memory'].message_type = _MEMORYSUMMARY
_TENANTRESPONSE.fields_by_name['createdAt'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TENANTRESPONSE.fields_by_name['updatedAt'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEKEYREQUEST.fields_by_name['keyType'].enum_type = _KEYTYPE
_KEYRESPONSE.fields_by_name['keyType'].enum_type = _KEYTYPE
DESCRIPTOR.message_types_by_name['CompressionConfiguration'] = _COMPRESSIONCONFIGURATION
DESCRIPTOR.message_types_by_name['TokenResponse'] = _TOKENRESPONSE
DESCRIPTOR.message_types_by_name['ServiceHealth'] = _SERVICEHEALTH
DESCRIPTOR.message_types_by_name['ServerHealthResponse'] = _SERVERHEALTHRESPONSE
DESCRIPTOR.message_types_by_name['SystemSummary'] = _SYSTEMSUMMARY
DESCRIPTOR.message_types_by_name['CpuSummary'] = _CPUSUMMARY
DESCRIPTOR.message_types_by_name['MemorySummary'] = _MEMORYSUMMARY
DESCRIPTOR.message_types_by_name['GenericClient'] = _GENERICCLIENT
DESCRIPTOR.message_types_by_name['TenantResponse'] = _TENANTRESPONSE
DESCRIPTOR.message_types_by_name['PaginationOptions'] = _PAGINATIONOPTIONS
DESCRIPTOR.message_types_by_name['PaginationResponse'] = _PAGINATIONRESPONSE
DESCRIPTOR.message_types_by_name['EnrollmentToken'] = _ENROLLMENTTOKEN
DESCRIPTOR.message_types_by_name['CreateKeyRequest'] = _CREATEKEYREQUEST
DESCRIPTOR.message_types_by_name['KeyResponse'] = _KEYRESPONSE
DESCRIPTOR.enum_types_by_name['Void'] = _VOID
DESCRIPTOR.enum_types_by_name['KeyType'] = _KEYTYPE
DESCRIPTOR.enum_types_by_name['FeatureFlag'] = _FEATUREFLAG
DESCRIPTOR.enum_types_by_name['ModelType'] = _MODELTYPE
DESCRIPTOR.enum_types_by_name['TechnologyType'] = _TECHNOLOGYTYPE
DESCRIPTOR.enum_types_by_name['CompressionType'] = _COMPRESSIONTYPE
DESCRIPTOR.enum_types_by_name['ClientType'] = _CLIENTTYPE
DESCRIPTOR.enum_types_by_name['UsageEventType'] = _USAGEEVENTTYPE
DESCRIPTOR.enum_types_by_name['ServerType'] = _SERVERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CompressionConfiguration = _reflection.GeneratedProtocolMessageType('CompressionConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _COMPRESSIONCONFIGURATION,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.CompressionConfiguration)
  })
_sym_db.RegisterMessage(CompressionConfiguration)

TokenResponse = _reflection.GeneratedProtocolMessageType('TokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOKENRESPONSE,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.TokenResponse)
  })
_sym_db.RegisterMessage(TokenResponse)

ServiceHealth = _reflection.GeneratedProtocolMessageType('ServiceHealth', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEHEALTH,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.ServiceHealth)
  })
_sym_db.RegisterMessage(ServiceHealth)

ServerHealthResponse = _reflection.GeneratedProtocolMessageType('ServerHealthResponse', (_message.Message,), {
  'DESCRIPTOR' : _SERVERHEALTHRESPONSE,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.ServerHealthResponse)
  })
_sym_db.RegisterMessage(ServerHealthResponse)

SystemSummary = _reflection.GeneratedProtocolMessageType('SystemSummary', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMSUMMARY,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.SystemSummary)
  })
_sym_db.RegisterMessage(SystemSummary)

CpuSummary = _reflection.GeneratedProtocolMessageType('CpuSummary', (_message.Message,), {
  'DESCRIPTOR' : _CPUSUMMARY,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.CpuSummary)
  })
_sym_db.RegisterMessage(CpuSummary)

MemorySummary = _reflection.GeneratedProtocolMessageType('MemorySummary', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYSUMMARY,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.MemorySummary)
  })
_sym_db.RegisterMessage(MemorySummary)

GenericClient = _reflection.GeneratedProtocolMessageType('GenericClient', (_message.Message,), {
  'DESCRIPTOR' : _GENERICCLIENT,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.GenericClient)
  })
_sym_db.RegisterMessage(GenericClient)

TenantResponse = _reflection.GeneratedProtocolMessageType('TenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _TENANTRESPONSE,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.TenantResponse)
  })
_sym_db.RegisterMessage(TenantResponse)

PaginationOptions = _reflection.GeneratedProtocolMessageType('PaginationOptions', (_message.Message,), {
  'DESCRIPTOR' : _PAGINATIONOPTIONS,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.PaginationOptions)
  })
_sym_db.RegisterMessage(PaginationOptions)

PaginationResponse = _reflection.GeneratedProtocolMessageType('PaginationResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAGINATIONRESPONSE,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.PaginationResponse)
  })
_sym_db.RegisterMessage(PaginationResponse)

EnrollmentToken = _reflection.GeneratedProtocolMessageType('EnrollmentToken', (_message.Message,), {
  'DESCRIPTOR' : _ENROLLMENTTOKEN,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.EnrollmentToken)
  })
_sym_db.RegisterMessage(EnrollmentToken)

CreateKeyRequest = _reflection.GeneratedProtocolMessageType('CreateKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKEYREQUEST,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.CreateKeyRequest)
  })
_sym_db.RegisterMessage(CreateKeyRequest)

KeyResponse = _reflection.GeneratedProtocolMessageType('KeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _KEYRESPONSE,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.common.KeyResponse)
  })
_sym_db.RegisterMessage(KeyResponse)


DESCRIPTOR._options = None
_SYSTEMSUMMARY.fields_by_name['cpu']._options = None
_SYSTEMSUMMARY.fields_by_name['memory']._options = None
_GENERICCLIENT.fields_by_name['clientId']._options = None
_GENERICCLIENT.fields_by_name['secret']._options = None
_CREATEKEYREQUEST.fields_by_name['name']._options = None
_CREATEKEYREQUEST.fields_by_name['keyType']._options = None
# @@protoc_insertion_point(module_scope)
